from backscattering_analyzer import logger
from backscattering_analyzer.experiment import Experiment


def show_projection(
    experiment: Experiment,
    start_frequency: float | None = None,
    end_frequency: float | None = None,
) -> None:
    """
    Show projection data with matplotlib
    """
    logger.debug(_("showing experiment result"))
    from matplotlib.pyplot import (
        loglog,
        show,
        legend,
        close,
        vlines,
        title,
        xlabel,
        ylabel,
    )

    excited = experiment.signals["excited"].psd().sqrt()
    reference = experiment.signals["reference"].psd().sqrt()
    loglog(
        experiment.projection.x,
        experiment.projection.y,
        label="projection",
    )  # type: ignore[ReportUnusedCallResult]
    loglog(excited.x, excited.y, label=_("excited bench"))  # type: ignore[ReportUnusedCallResult]
    loglog(reference.x, reference.y, label=_("reference bench"))  # type: ignore[ReportUnusedCallResult]
    loglog(
        (experiment.projection + reference).x,
        (experiment.projection + reference).y,
        label=_("sum reference + excited"),
    )  # type: ignore[ReportUnusedCallResult]
    if start_frequency is not None:
        vlines(
            [
                start_frequency,
            ],
            min(experiment.projection.y),
            max(experiment.projection.y),
            color="k",
        )  # type: ignore[ReportUnusedCallResult]
    if end_frequency is not None:
        vlines(
            [
                end_frequency,
            ],
            min(experiment.projection.y),
            max(experiment.projection.y),
            color="k",
        )  # type: ignore[ReportUnusedCallResult]
    legend()  # type: ignore[ReportUnusedCallResult]
    title(experiment.bench)  #  type: ignore[ReportUnusedCallResult]
    xlabel(_("frequency (Hz)"))  # type: ignore[ReportUnusedCallResult]
    ylabel(_("stray ($\\frac{1} {\\sqrt {Hz}}$)"))  #  type: ignore[ReportUnusedCallResult]
    show()
    close()
    logger.debug(_("experiment result showed"))
